# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mcskin']

package_data = \
{'': ['*'],
 'mcskin': ['models/resnet10/*',
            'models/upconv7/*',
            'models/upresnet10/*',
            'models/vgg7/*']}

install_requires = \
['Pillow>=9.0.0,<10', 'layeredimage>=2022,<2024', 'waifu2x>=2022,<2024']

entry_points = \
{'console_scripts': ['mcskin = mcskin:cli']}

setup_kwargs = {
    'name': 'mcskin',
    'version': '2022',
    'description': 'For some raw skin, generate 1.0, 1.8 and 1.8 bedrock skins.',
    'long_description': '[![GitHub top language](https://img.shields.io/github/languages/top/FHPythonUtils/MCSkin.svg?style=for-the-badge)](../../)\n[![Repository size](https://img.shields.io/github/repo-size/FHPythonUtils/MCSkin.svg?style=for-the-badge)](../../)\n[![Issues](https://img.shields.io/github/issues/FHPythonUtils/MCSkin.svg?style=for-the-badge)](../../issues)\n[![License](https://img.shields.io/github/license/FHPythonUtils/MCSkin.svg?style=for-the-badge)](/LICENSE.md)\n[![Commit activity](https://img.shields.io/github/commit-activity/m/FHPythonUtils/MCSkin.svg?style=for-the-badge)](../../commits/master)\n[![Last commit](https://img.shields.io/github/last-commit/FHPythonUtils/MCSkin.svg?style=for-the-badge)](../../commits/master)\n[![PyPI Downloads](https://img.shields.io/pypi/dm/mcskin.svg?style=for-the-badge)](https://pypistats.org/packages/mcskin)\n[![PyPI Total Downloads](https://img.shields.io/badge/dynamic/json?style=for-the-badge&label=total%20downloads&query=%24.total_downloads&url=https%3A%2F%2Fapi.pepy.tech%2Fapi%2Fprojects%2Fmcskin)](https://pepy.tech/project/mcskin)\n[![PyPI Version](https://img.shields.io/pypi/v/mcskin.svg?style=for-the-badge)](https://pypi.org/project/mcskin)\n\n<!-- omit in toc -->\n# MCSkin\n\n<img src="readme-assets/icons/name.png" alt="Project Icon" width="750">\n\nFor some raw skin, generate 1.0, 1.8 and 1.8 bedrock skins.\n\nMore features in the future.\n\n## Help\n\n```raw\nusage: __main__.py [-h] filepath\n\nFor some raw skin, generate 1.0, 1.8 and 1.8 bedrock skins.\n\npositional arguments:\n  filepath    Path to skin source\n\noptional arguments:\n  -h, --help  show this help message and exit\n```\n\n<!-- omit in toc -->\n## Table of Contents\n\n- [Help](#help)\n- [Documentation](#documentation)\n- [Screenshots](#screenshots)\n- [Install With PIP](#install-with-pip)\n- [Language information](#language-information)\n\t- [Built for](#built-for)\n- [Install Python on Windows](#install-python-on-windows)\n\t- [Chocolatey](#chocolatey)\n\t- [Windows - Python.org](#windows---pythonorg)\n- [Install Python on Linux](#install-python-on-linux)\n\t- [Apt](#apt)\n\t- [Dnf](#dnf)\n- [Install Python on MacOS](#install-python-on-macos)\n\t- [Homebrew](#homebrew)\n\t- [MacOS - Python.org](#macos---pythonorg)\n- [How to run](#how-to-run)\n\t- [Windows](#windows)\n\t- [Linux/ MacOS](#linux-macos)\n- [Download Project](#download-project)\n\t- [Clone](#clone)\n\t\t- [Using The Command Line](#using-the-command-line)\n\t\t- [Using GitHub Desktop](#using-github-desktop)\n\t- [Download Zip File](#download-zip-file)\n- [Community Files](#community-files)\n\t- [Licence](#licence)\n\t- [Changelog](#changelog)\n\t- [Code of Conduct](#code-of-conduct)\n\t- [Contributing](#contributing)\n\t- [Security](#security)\n\t- [Support](#support)\n\t- [Rationale](#rationale)\n\n## Documentation\n\nSee the [Docs](/DOCS/) for more information.\n\n## Screenshots\n\nExample output for a skin, 10 (mc 1.0+), 18 (mc 1.8+) and 18b (mc 1.8+ bedrock).\nInput=18 (mc 1.8+)\n\n<div>\n<img src="readme-assets/screenshots/desktop/18/10.png" alt="Screenshot 1" width="200">\n<img src="readme-assets/screenshots/desktop/18/18.png" alt="Screenshot 2" width="200">\n<img src="readme-assets/screenshots/desktop/18/18b.png" alt="Screenshot 3" width="200">\n</div>\n\nExample output for a skin, 10 (mc 1.0+), 18 (mc 1.8+) and 18b (mc 1.8+ bedrock).\nInput=10 (mc 1.0+)\n\n<div>\n<img src="readme-assets/screenshots/desktop/10/10.png" alt="Screenshot 1" width="200">\n<img src="readme-assets/screenshots/desktop/10/18.png" alt="Screenshot 2" width="200">\n<img src="readme-assets/screenshots/desktop/10/18b.png" alt="Screenshot 3" width="200">\n</div>\n\n## Install With PIP\n\n```python\npip install mcskin\n```\n\nHead to https://pypi.org/project/MCSkin/ for more info\n\n## Language information\n\n### Built for\n\nThis program has been written for Python versions 3.7 - 3.10 and has been tested with both 3.7 and\n3.10\n\n## Install Python on Windows\n\n### Chocolatey\n\n```powershell\nchoco install python\n```\n\n### Windows - Python.org\n\nTo install Python, go to https://www.python.org/downloads/windows/ and download the latest\nversion.\n\n## Install Python on Linux\n\n### Apt\n\n```bash\nsudo apt install python3.x\n```\n\n### Dnf\n\n```bash\nsudo dnf install python3.x\n```\n\n## Install Python on MacOS\n\n### Homebrew\n\n```bash\nbrew install python@3.x\n```\n\n### MacOS - Python.org\n\nTo install Python, go to https://www.python.org/downloads/macos/ and download the latest\nversion.\n\n## How to run\n\n### Windows\n\n- Module\n\t`py -3.x -m [module]` or `[module]` (if module installs a script)\n\n- File\n\t`py -3.x [file]` or `./[file]`\n\n### Linux/ MacOS\n\n- Module\n\t`python3.x -m [module]` or `[module]` (if module installs a script)\n\n- File\n\t`python3.x [file]` or `./[file]`\n\n## Download Project\n\n### Clone\n\n#### Using The Command Line\n\n1. Press the Clone or download button in the top right\n2. Copy the URL (link)\n3. Open the command line and change directory to where you wish to\nclone to\n4. Type \'git clone\' followed by URL in step 2\n\t```bash\n\tgit clone https://github.com/FHPythonUtils/MCSkin\n\t```\n\nMore information can be found at\nhttps://help.github.com/en/articles/cloning-a-repository\n\n#### Using GitHub Desktop\n\n1. Press the Clone or download button in the top right\n2. Click open in desktop\n3. Choose the path for where you want and click Clone\n\nMore information can be found at\nhttps://help.github.com/en/desktop/contributing-to-projects/cloning-a-repository-from-github-to-github-desktop\n\n### Download Zip File\n\n1. Download this GitHub repository\n2. Extract the zip archive\n3. Copy/ move to the desired location\n\n## Community Files\n\n### Licence\n\nMIT License\n(See the [LICENSE](/LICENSE.md) for more information.)\n\n### Changelog\n\nSee the [Changelog](/CHANGELOG.md) for more information.\n\n### Code of Conduct\n\nOnline communities include people from many backgrounds. The *Project*\ncontributors are committed to providing a friendly, safe and welcoming\nenvironment for all. Please see the\n[Code of Conduct](https://github.com/FHPythonUtils/.github/blob/master/CODE_OF_CONDUCT.md)\n for more information.\n\n### Contributing\n\nContributions are welcome, please see the\n[Contributing Guidelines](https://github.com/FHPythonUtils/.github/blob/master/CONTRIBUTING.md)\nfor more information.\n\n### Security\n\nThank you for improving the security of the project, please see the\n[Security Policy](https://github.com/FHPythonUtils/.github/blob/master/SECURITY.md)\nfor more information.\n\n### Support\n\nThank you for using this project, I hope it is of use to you. Please be aware that\nthose involved with the project often do so for fun along with other commitments\n(such as work, family, etc). Please see the\n[Support Policy](https://github.com/FHPythonUtils/.github/blob/master/SUPPORT.md)\nfor more information.\n\n### Rationale\n\nThe rationale acts as a guide to various processes regarding projects such as\nthe versioning scheme and the programming styles used. Please see the\n[Rationale](https://github.com/FHPythonUtils/.github/blob/master/RATIONALE.md)\nfor more information.\n',
    'author': 'FredHappyface',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/FHPythonUtils/MCSkin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
